function SelfSupAM_Boston()
%   SelfSupAM_Boston.m
%       Exercises Self-Supervised ARTMAP on the Boston benchmark.
%
%   Greg Amis
%   Technology Lab
%   Dept. of Cognitive & Neural Systems
%   Boston University
%   26 March 2009
%
%   Licensing Policy
%   This implementation is made available to the general public under the terms 
%   of Copyleft, as defined by the <a href="http://www.fsf.org/">Free Software Foundation</a> 
%   (see discussion <a href="http://www.gnu.org/copyleft/copyleft.html">here</a> for example). 
%   As such, it is available free of charge, and may be copied, redistributed, or modified, 
%   as long as any resulting work is distributed under the same terms of
%   Copyleft.


%% Load data
% This cell depends on having the data file boston_strips.mat in the
% current directory. This file can be created by running the script
% boston_from_classer.m (if Classer is installed), or by allowing this script to download
% it from the CNS Tech Lab website.
BOS_STRIPS_URL = 'http://cns.bu.edu/techlab/files/resources/datasets/boston_strips.zip';
if ~exist('boston_strips.mat','file')
    dlgMsg = ['The Boston benchmark data source file boston_strips.mat ',...
        'could not be found at ',pwd,'. Do you want to download it from ',...
        'the CNS Techlab website?'];
    btnPressed = questdlg(dlgMsg);
    if strcmp(btnPressed,'Yes')
        try unzip(BOS_STRIPS_URL);
        catch
            e = lasterror;
            if strfind(e.identifier,'urlwriteError')
                error(e.identifier,...
                     ['Either there is a problem with your internet connection '...
                      'or the boston strips dataset is no longer available at '...
                      'the expected url, %s. Please check the tech lab website '...
                      'for updates, http://cns.bu.edu/techlab'],BOS_STRIPS_URL);
            else
                error(e);
            end;                
        end;
    else
        return;
    end;
end;
strips = []; classNames = {};
load('boston_strips.mat');
F = length(strips);

% Unlabel road pixels. 
%   Road widths are so much smaller than the pixel width,
%   attempting to label pixels as road is unreliable.
ROAD = 5;
for f = 1:F
    %Unlabel road pixels
    isRoad = strips(f).labels==ROAD;
    strips(f).labels(isRoad) = -1; %unlabeled
    %Shift classes after road up one
    afterRoad = strips(f).labels>ROAD;
    strips(f).labels(afterRoad) = strips(f).labels(afterRoad) - 1;
end;
%Remove road from classNames
classNames(ROAD) = [];

% Define Stage 1 feature subsets
subsets.Full = 1:38;
subsets.Visual = [1:3,10:12,19:38];
subsets.Raw = 1:9;
subsets.RedGreen = [2,3,11,12,19:21];
subsets.BlueYellow = [1,10,22:24];
subsets.RawBlue = 1;
subsets.RawRedGreen = [2,3];
subsetNames = {'Full','Visual','Raw','Red-Green','Blue-Yellow','Raw Blue','Raw Red-Green'}; %#ok<NASGU>

testActuals = cat(2,strips(:).labels);
testActuals(testActuals==-1) = [];

%% Run cross validation
% Requires running "Load data" cell above.
btnPressed = questdlg('This script takes about 50 seconds to run. Do you want to contiue?');
if ~strcmp(btnPressed,'Yes')
    return;
end;

s1features = subsets.BlueYellow;
[s1Preds,s2Preds] = SelfSupAM_crossValidation( strips, s1features,...
    'E2',2, 'ClassCap',250, 'SamplerSeed',1 );

figure('Name','After Stage 1','Position',[241 470 643 420],'Toolbar','none');
conf_mat( testActuals, cat(2,s1Preds{:}), classNames );

figure('Name','After Stage 2','Position',[241 30 643 420],'Toolbar','none');
conf_mat( testActuals, cat(2,s2Preds{:}), classNames );





