function SelfSupAM_loadJava( )
%   SelfSupAM_loadJava Loads the required java jar file.%   
%
%   Greg Amis
%   Technology Lab
%   Dept. of Cognitive & Neural Systems
%   Boston University
%   29 March 2009
%
%   Licensing Policy
%   This implementation is made available to the general public under the terms 
%   of Copyleft, as defined by the <a href="http://www.fsf.org/">Free Software Foundation</a> 
%   (see discussion <a href="http://www.gnu.org/copyleft/copyleft.html">here</a> for example). 
%   As such, it is available free of charge, and may be copied, redistributed, or modified, 
%   as long as any resulting work is distributed under the same terms of Copyleft.

OLDEST_JVM_VERSION = 1.5;

if ~usejava('jvm')
    error('Self-Supervised ARTMAP requires java. Please run matlab with java enabled.');
end;

jv = version('-java');
[s e ex m tokens]  = regexp(jv,'Java\s(\d+\.\d+)');
if isempty(tokens)
    warning('SelfSupAM:UnknownJVMversion','Could not verify Java version. Requires >=1.5');
else
    jv = str2double(tokens{1}{1});
    if jv<OLDEST_JVM_VERSION
        error( ['SelfSupARTMAP requires at least java version %g, ',...
            'but it looks like you''re running version %g. ',...
            'Please make sure you have a recent version of java installed ',...
            'and that Matlab is using it, i.e., the system environment variable ',...
            'MATLAB_JAVA is set to the correct path.'],...
            OLDEST_JVM_VERSION, jv );
    end;
end;

if exist('edu.bu.cns.classifiers.artmap.SelfSupervisedARTMAP','class')~=8
    p = mfilename('fullpath');
    p = strrep(p,'SelfSupAM_loadJava','lib.jar');
    javaaddpath(p);
end;

