function model = SelfSupAM_trainStage2( model, inputs )
%   SelfSupAM_trainStage2 Performs Stage 2 training on Self-Supervised ARTMAP.
%
%   model = SelfSupAM_trainStage2( model, inputs ) 
%     Performs Stage 2 training on the passed Self-Supervised ARTMAP model.
%        model ~ Java object returned by SelfSupAM_trainStage1       
%        inputs ~ MxN floating point (double|single), 
%           where N is the number of inputs, and all values are already
%           scaled to the unit interval: all(inputs(:)>=0 & inputs(:)<=1)
%     Returns model reference, but since model is a java object (passed by
%     reference), this is not really necessary.
%           
%   Based on:   Amis, G., & Carpenter, G.A. (2009). 
%                   Self-Supervised ARTMAP. (in preparation)
%   
%
%   Greg Amis
%   Technology Lab
%   Dept. of Cognitive & Neural Systems
%   Boston University
%   26 March 2009
%
%   Licensing Policy
%   This implementation is made available to the general public under the terms 
%   of Copyleft, as defined by the <a href="http://www.fsf.org/">Free Software Foundation</a> 
%   (see discussion <a href="http://www.gnu.org/copyleft/copyleft.html">here</a> for example). 
%   As such, it is available free of charge, and may be copied, redistributed, or modified, 
%   as long as any resulting work is distributed under the same terms of Copyleft.

if nargin~=2, error('Model and inputs required.'); end;


jinputs = edu.bu.cns.data.InputsImpl( inputs' );

model.trainStage2(jinputs);

