/**
 *	AbsSelfSupClassifier.java
 *
 *  Greg Amis
 *  Technology Lab
 *  Dept. of Cognitive & Neural Systems
 *  Boston University
 *  Nov 13, 2008
 *
 *  Licensing Policy
 *  This implementation is made available to the general public under the terms 
 *  of Copyleft, as defined by the <a href="http://www.fsf.org/">Free Software Foundation</a> 
 *  (see discussion <a href="http://www.gnu.org/copyleft/copyleft.html">here</a> for example). 
 *  As such, it is available free of charge, and may be copied, redistributed, or modified, 
 *  as long as any resulting work is distributed under the same terms of Copyleft.
 */
package edu.bu.cns.classifiers;

import java.io.Serializable;

import edu.bu.cns.data.Input;
import edu.bu.cns.data.Inputs;
import edu.bu.cns.data.LabeledInputs;
import edu.bu.cns.util.DeepCopier;

/**
 *
 */
public abstract class AbsSelfSupClassifier implements SelfSupervisedClassifier, Cloneable, Serializable {
	
	
	public final void train(final LabeledInputs labeledInputs) {
		trainStage1(labeledInputs);		
	}
	
	public int[] test( final Inputs<?> inputs ) {
		
		final int[] preds = new int[inputs.size()];
		int n = 0;
		for ( final Input input : inputs) {
			preds[n++] = test(input);
		}
			
		return preds;
	}
	
	public float[][] testDistribution( final Inputs<?> inputs ) 
	{
		final float[][] pKs = new float[inputs.size()][];
		int n = 0;
		for ( final Input input : inputs) {
			pKs[n++] = testDistribution(input);
		}
		
		return pKs;			
	}
	
	
	
	public int[] exercise(final LabeledInputs trainingInputs, final Inputs<?> testInputs) {
		trainStage1(trainingInputs);
		return test(testInputs);
	}

	public float[][] exerciseDistribution( 
			final LabeledInputs trainingInputs,
			final Inputs<?> testInputs) {
		trainStage1(trainingInputs);
		return testDistribution(testInputs);
	}

	public int[] exercise( final LabeledInputs stage1Training,
			final Inputs<?> stage2Training, final Inputs<?> testInputs ) {
		trainStage1(stage1Training);
		trainStage2(stage2Training);
		return test(testInputs);
	}
	
	public float[][] exerciseDistribution( final LabeledInputs stage1Training,
			final Inputs<?> stage2Training, final Inputs<?> testInputs ) {
		trainStage1(stage1Training);
		trainStage2(stage2Training);
		return testDistribution(testInputs);
	}
	
	public SelfSupervisedClassifier clone() {
		return DeepCopier.createDeepCopy(this);
	}

}
