/**
 *	InputsLabelsLengthMismatchException.java
 *
 *  Greg Amis
 *  Technology Lab
 *  Dept. of Cognitive & Neural Systems
 *  Boston University
 *  Nov 15, 2008
 *
 *  Licensing Policy
 *  This implementation is made available to the general public under the terms 
 *  of Copyleft, as defined by the <a href="http://www.fsf.org/">Free Software Foundation</a> 
 *  (see discussion <a href="http://www.gnu.org/copyleft/copyleft.html">here</a> for example). 
 *  As such, it is available free of charge, and may be copied, redistributed, or modified, 
 *  as long as any resulting work is distributed under the same terms of Copyleft.
 */
package edu.bu.cns.data;

import edu.bu.cns.util.FormattableException;

/**
 *	Thrown when {@link LabeledInputsImpl} is passed an inputs array
 * and a labels array of different lengths.
 */
public class InputsLabelsLengthMismatchException extends FormattableException {

	private static final long serialVersionUID = -3879618973145683265L;
		
	public InputsLabelsLengthMismatchException( final int inputsLength, final int labelsLength)
	{
		super(inputsLength,labelsLength);
	}
	
	@Override
	protected String getMsgFmt() {
		return "LabeledInputsImpl(float[][],int[],int) requires " +
		"that the inputs array be of the same length as the labels array, " +
		"but inputs.length=%d!=labels.length=%d";
	}

}
