/**
 *	LabeledInput.java
 *
 *  Greg Amis
 *  Technology Lab
 *  Dept. of Cognitive & Neural Systems
 *  Boston University
 *  Nov 13, 2008
 *
 *  Licensing Policy
 *  This implementation is made available to the general public under the terms 
 *  of Copyleft, as defined by the <a href="http://www.fsf.org/">Free Software Foundation</a> 
 *  (see discussion <a href="http://www.gnu.org/copyleft/copyleft.html">here</a> for example). 
 *  As such, it is available free of charge, and may be copied, redistributed, or modified, 
 *  as long as any resulting work is distributed under the same terms of Copyleft.
 */
package edu.bu.cns.data;

import java.util.Arrays;

/**
 *
 */
public interface LabeledInput extends Input {
	
	/**
	 * @return class label for this input
	 */
	public int label();
	
	/**
	 * @return true if the label is known
	 */
	public boolean isLabeled();
	
	/**
	 * Basic implementation for LabeledInput
	 */
	public class Impl implements LabeledInput {
		
		private static final int UNKNOWN_LABEL = -1; 
		
		private float[] features;
		private int label;
		public Impl(final float[] a, final int K) { 
			features = a; 
			label = K;
		}
		public float[] features() { return features; }
		public boolean isLabeled() { return label!=UNKNOWN_LABEL; }
		public int label() { return label; }
		
		@Override
		public String toString() {
			return String.format("K=%d,a=%s",label,Arrays.toString(features));
		}
	
	}

}
