/**
 *	FormattableException.java
 *
 *  Greg Amis
 *  Technology Lab
 *  Dept. of Cognitive & Neural Systems
 *  Boston University
 *  Nov 17, 2008
 *
 *  Licensing Policy
 *  This implementation is made available to the general public under the terms 
 *  of Copyleft, as defined by the <a href="http://www.fsf.org/">Free Software Foundation</a> 
 *  (see discussion <a href="http://www.gnu.org/copyleft/copyleft.html">here</a> for example). 
 *  As such, it is available free of charge, and may be copied, redistributed, or modified, 
 *  as long as any resulting work is distributed under the same terms of Copyleft.
 */
package edu.bu.cns.util;

/**
 *	Provides a base class for exceptions with easy-to-format message strings.
 */
public abstract class FormattableException extends RuntimeException {
	
	private final String msg;
	
	/**
	 * Instantiates the exception, building the message 
	 * using getMsgFmt and args.
	 * @param args
	 */
	public FormattableException(Object... args) {
		super();
		msg = String.format(getMsgFmt(), args);
	}

	protected abstract String getMsgFmt();
	
	@Override
	public String getMessage() { return msg; }
	
	

}
