/**
 *	IntArrayList.java
 *
 *  Greg Amis
 *  Technology Lab
 *  Dept. of Cognitive & Neural Systems
 *  Boston University
 *  Oct 13, 2008
 *
 *   Licensing Policy
 *  This implementation is made available to the general public under the terms 
 *  of Copyleft, as defined by the <a href="http://www.fsf.org/">Free Software Foundation</a> 
 *  (see discussion <a href="http://www.gnu.org/copyleft/copyleft.html">here</a> for example). 
 *  As such, it is available free of charge, and may be copied, redistributed, or modified, 
 *  as long as any resulting work is distributed under the same terms of Copyleft. 
 */
package edu.bu.cns.util;

import java.util.ArrayList;
import java.util.Arrays;

/**
 *	Functions similarly to {@link ArrayList}, but backed by int array.
 */
public class IntArrayList {

	private int[] elementData;
	private int size = 0;
	
	/**
	 * Creates an IntArrayList of size 0 with the passed initial capacity
	 * @param size
	 */
	public IntArrayList(final int initCapacity) {
		elementData = new int[initCapacity];
	}
	
	/** Sets list size to 0. */
	public void clear() {
		size = 0;
	}

	public void add(int i) {
		if (size==elementData.length)
			ensureCapacity((size*3)/2 + 1);
		elementData[size++] = i;		
	}
	
	public int get(int i) {
		if (i>=size) 
			throw new IndexOutOfBoundsException("Index: "+i+", Size: "+size);
		return elementData[i];
	}

	public boolean isEmpty() {
		return size==0;
	}

	public int size() {
		return size;
	}
	
	public int[] toArray() { return Arrays.copyOf(elementData,size); }
	
	public final void ensureCapacity(final int newMaxSize) {
    	if (newMaxSize<=elementData.length) return;
		final int[] newe = new int[newMaxSize];
		System.arraycopy(elementData, 0, newe, 0, size);
		this.elementData = newe;
    }
	
	@Override
	public String toString() {
		return Arrays.toString(elementData);
	}

}
