/**
 *	PowTest.java
 *
 *  Greg Amis
 *  Technology Lab
 *  Dept. of Cognitive & Neural Systems
 *  Boston University
 *  Nov 17, 2008
 *
 *  Licensing Policy
 *  This implementation is made available to the general public under the terms 
 *  of Copyleft, as defined by the <a href="http://www.fsf.org/">Free Software Foundation</a> 
 *  (see discussion <a href="http://www.gnu.org/copyleft/copyleft.html">here</a> for example). 
 *  As such, it is available free of charge, and may be copied, redistributed, or modified, 
 *  as long as any resulting work is distributed under the same terms of Copyleft.
 */
package edu.bu.cns.util;

import junit.framework.TestCase;

/**
 *
 */
public class PowTest extends TestCase {
	
	private static final float[] bases = { 
		-3.25e13f, -5f, -1f, -1e-3f, 0f, 1e-3f, 1f, 5f, 3.3f, 23.2333f, 3.25e13f, 
		Float.NEGATIVE_INFINITY, -Float.MAX_VALUE, -Float.MIN_VALUE, 
		Float.POSITIVE_INFINITY, Float.MAX_VALUE, Float.MIN_VALUE };
	
	public void testZeroPow() {
		testPow( 0f, "ZeroPow" );
	}
	
	public void testIntPow() {
		for (float p : new float[]{ 2, 3, 15, 11 }) {
			testPow( p, "IntPow" );
		}
	}
	
	public void testMinIntPow() {
		for (float p : new float[]{ -2, -3, -15 }) {
			testPow( p, "NegIntPow" );
		}
	}
	
	public void testMathPow() {
		testPow(5.3f,"MathPow");
		testPow(-1e-2f,"MathPow");
	}
	
	private void testPow(final float p, String className) {
		
		final Pow pow = Pow.createPow(p);
		assertEquals(className,pow.getClass().getSimpleName());
		
		for (final float base : bases) {
			final float actual = (float) Math.pow(base, pow.p().doubleValue());
			assertEqualsIgnoreNaN(base+"^"+p,actual, pow.calc(base),5e-6f*Math.abs(actual));
		}
	}
	
	public static void assertEqualsIgnoreNaN( final String msg, 
			final float expected, final float actual, final float delta)
	{
		if (Float.isNaN(expected) && Float.isNaN(actual)) return;
		assertEquals(msg,expected,actual,delta);
	}

}
